
#import <Foundation/Foundation.h>
#import "PGIpsReader.h"
#import "PGSwipeUnimag.h"
#import "PGAudioJackConnectionDetector.h"


/**
 @brief Detects whether an object attached to the audio jack is a UniMag (Shuttle) reader, an IPS reader, or neither.
 */
@interface PGAudioJackCardReaderTypeDetector : NSObject<IpsDelegate, PGSwipeDelegate, PGAudioJackConnectionDetectorDelegate, IpsCommunicationTestDelegate>

@property (nonatomic, readonly) bool detectedIpsReader;
@property (nonatomic, readonly) bool detectedUniMagReader;
@property (nonatomic, retain) PGSwipeDevice *detectedSwipeDevice;


/**
 @brief Asynchronously attempts to detect the card reader type currently attached to the audio jack.
 @details A communication test is first attempted for an IPS reader.  If that fails, an attempt is made to power up a UniMag (Shuttle) card reader.  Upon completion, the notification "AudioJackReaderDetectionFinished" is posted.
 @note Both the IPS communication test and the UniMag power up produce very loud tones through the audio jack.  If speakers or headphones are attached, the tones would be unpleasant to the user.  It is recommended that the user be warned and allowed to remove headphones before calling this function.  This library suppresses notifications from the UniMag reader during autodetect.
 In order to detect the devices, all of the underlying card reader libraries must be loaded.  Under some circumstances, these libraries may not unload cleanly, resulting in unreliable use of the card reader.  This function should not be called unless necessary.
 */
-(void)beginAutodetectCardReader;

@end
