
#import <Foundation/Foundation.h>
#import "PGSwipeDevice.h"
#import "PGIpsReader.h"
#import "PGAudioJackConnectionDetector.h"

/**
 @brief The controller class for IPS swipe readers.
 @note This class should not be instantiated directly.  Create a PGSwipeController instead and use its ipsReader property.
 */
@interface PGSwipeIps : PGSwipeDevice<IpsDelegate, PGAudioJackConnectionDetectorDelegate>


-(id) initWithDelegate:(id<PGSwipeDelegate>)delegate;

/**
 @brief Closes the reader and unsubscribes from events.  Must be called before releasing.
 */
-(void)shutdown;

/**
 @brief Asynchronously sends a communication test message to the reader with a response returned to the communicationTestDelegate.
 @note Allow at least 1.2 seconds to pass for the reader to initialize before calling this function or the communication test message may not be received by the reader.  The reader begins to initialize when it is plugged into the audio jack or when this PGSwipeIps class is init-ed, whichever is later).
 */
-(void)beginTestCommunication:(id<IpsCommunicationTestDelegate>)communicationTestDelegate;

@end
