package com.example.paymentgatewayswipesample;


import com.SafeWebServices.PaymentGateway.*;
import com.SafeWebServices.PaymentGateway.PGSwipeController.SwipeListener;

import android.os.Bundle;
import android.app.Activity;
import android.view.Menu;
import android.view.View;
import android.widget.EditText;
import android.widget.TextView;

public class MainActivity extends Activity implements SwipeListener {
    
    PGSwipeController swipeController;
    PGSwipedCard card;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        /*
         * Set up the swipe device to be used.
         * Currently, either SwipeDevice.IPS or SwipeDevice.UNIMAG can be used.
         */
        //this.swipeController = new PGSwipeController(this, PGSwipeDevice.SwipeDevice.IPS);
		this.swipeController = new PGSwipeController(this, PGSwipeDevice.SwipeDevice.UNIMAG);
        /*
         * Would change default values here.
         * 
         * For example:
         * this.swipeController.getDevice().setSwipeTimeout(30);
         * this.swipeController.getDevice().setAlwaysAcceptSwipe(false);
         * this.swipeController.getDevice().setActivateReaderOnConnect(false);
         */
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.activity_main, menu);
        return true;
    }
    /**
     * Creates a transaction and sends it to the gateway.
     * @param v
     */
    public void onClickSend(View v) {
        //Create direct post string
        String transInfo = "username=mobiledemo&password=test1234&type=sale&amount=5.00&" + this.card.getDirectPostString(false);
        //
        //Send transaction information to the gateway(Not part of the SDK)
        SendToGateway send = new SendToGateway(transInfo, this.getCurrentFocus());
        Thread thread = new Thread(send);
        thread.start();
    }
    /**
     * Requests a new swipe.
     * @param v
     */
    public void onClickReset(View v) {
        this.swipeController.getDevice().requestSwipe();
    }
    /**
     * Pauses the swipe device so it will not create any more calls.
     * @param v
     */
    public void onClickPause(View v) {
        this.swipeController.getDevice().stopSwipeController();
    }
    /**
     * Resumes the swipe device after being paused.
     * Only way to resume functionality to the swipe device after it is paused.
     * @param v
     */
    public void onClickResume(View v) {
        this.swipeController.getDevice().restartSwipeController();
    }
    
    /*
     * Functions to modify the view and display swiper related information for testing
     */
    public String getText(boolean status) {
        if (status) {
            return "TRUE";
        } else {
            return "FALSE";
        }
    }
    public void updateMsgView(String text) {
        TextView msg = (TextView)findViewById(R.id.textMsg);
        msg.setText((CharSequence) text);
    }
    public void updateSwipeStatus(boolean status) {
        TextView swipe = (TextView)findViewById(R.id.textSwipe);
        swipe.setText((CharSequence) getText(status));
    }
    public void updateActiveStatus(boolean status) {
        TextView active = (TextView)findViewById(R.id.textActive);
        active.setText((CharSequence) getText(status));
    }
    public void updateConnectedStatus(boolean status) {
        TextView conn = (TextView)findViewById(R.id.textConnected);
        conn.setText((CharSequence) getText(status));
    }
    public void updateCardView(String text) {
        EditText ccnum = (EditText)findViewById(R.id.ccnumber);
        ccnum.setText((CharSequence) text);
    }
    public void updateExpView(String text) {
        EditText ccexp = (EditText)findViewById(R.id.ccexp);
        ccexp.setText((CharSequence) text);
    }
    /*
     * Functions called by the swipe device.(non-Javadoc)
     * @see com.SafeWebServices.PaymentGateway.SwipeController.SwipeListener#onSwipedCard(com.SafeWebServices.PaymentGateway.PaymentGatewayCard, com.SafeWebServices.PaymentGateway.SwipeDevice)
     */
    /**
     * Handles a card swipe event.
     */
    @Override
    public void onSwipedCard(final PGSwipedCard card, final PGSwipeDevice swiper) {
        this.card = card;
        //allows event to modify the view
        this.runOnUiThread(new Runnable() {
            public void run() {
                if (card != null) {
                    updateCardView(((PGEncryptedSwipedCard)card).getMaskedCardNumber());
                    updateExpView(((PGEncryptedSwipedCard)card).getExpirationDate());
                    updateMsgView(swiper.getDefaultMsg());
                    updateSwipeStatus(swiper.getIsReadyForSwipe());
                    updateActiveStatus(swiper.getIsActivated());
                    updateConnectedStatus(swiper.getIsConnected());
                } else {
                    updateCardView("NULL");
                }
            }
        });
    }
    /**
     * Is called when the swipe device is ready to accept a card swipe.
     */
    @Override
    public void onDeviceReadyForSwipe(final PGSwipeDevice swiper) {
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
            }
        });
    }
    /**
     * Is called when the swipe device is no longer ready to accept a card swipe.
     */
    @Override
    public void onDeviceUnreadyForSwipe(final PGSwipeDevice swiper, PGSwipeDevice.ReasonUnreadyForSwipe reason) {
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
            }
        });
    }
    /**
     * Is called when the swipe device is connected to the android device.
     */
    @Override
    public void onDeviceConnected(final PGSwipeDevice swiper) {
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
                updateActiveStatus(swiper.getIsActivated());
                updateConnectedStatus(swiper.getIsConnected());
            }
        });
    }
    /**
     * Is called when the swipe device is unplugged from the android device.
     */
    @Override
    public void onDeviceDisconnected(final PGSwipeDevice swiper) {
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
                updateActiveStatus(swiper.getIsActivated());
                updateConnectedStatus(swiper.getIsConnected());
            }
        });
    }
    /**
     * Is called when the swipe device is activated.
     * At this point, a swipe can be requested.
     */
    @Override
    public void onDeviceActivationFinished(final PGSwipeDevice swiper) {
        /*
         * If always accept swipe is set to false.
         */
        if (!swiper.getIsReadyForSwipe()) {
            swiper.requestSwipe();
        }
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
                updateActiveStatus(swiper.getIsActivated());
                updateConnectedStatus(swiper.getIsConnected());
            }
        });
    }
    /**
     * Called when a swipe can no longer be requested.
     */
    @Override
    public void onDeviceDeactivated(final PGSwipeDevice swiper) {
        this.runOnUiThread(new Runnable() {
            public void run() {
                updateMsgView(swiper.getDefaultMsg());
                updateSwipeStatus(swiper.getIsReadyForSwipe());
                updateActiveStatus(swiper.getIsActivated());
                updateConnectedStatus(swiper.getIsConnected());
            }
        });
    }
}
